==> dma-1.0.3.tar.gz: dma-1.0.3/setup.py <==
from setuptools import setup, find_packages

setup(
    name                           = "dma"                                                                                                  ,
    version                        = "1.0.3"                                                                                                ,
    description                    = "This Module Returns ASCII Art & Text in Many Different Variations Depending on The Called Function."  ,
    long_description_content_type  = "text/markdown"                                                                                        ,
    author                         = "Anvil"                                                                                                ,
    author_email                   = "_@chimera.rip"                                                                                        ,
    url                            = "https://github.com/vChimera/anvilly"                                                                  ,
    packages                       = find_packages()                                                                                        ,
    classifiers                    = [
        "Programming Language :: Python :: 3"                                                                                               ,
        "License :: OSI Approved :: MIT License"                                                                                            ,
        "Operating System :: OS Independent"                                                                                                ,
    ]                                                                                                                                       ,
    python_requires                = ">=3.6"                                                                                                ,
)

==> dma-1.0.8.tar.gz: dma-1.0.8/setup.py <==
from setuptools import setup, find_packages

setup(
    name                           = "dma"                                                                                                  ,
    version                        = "1.0.8"                                                                                                ,
    description                    = "This Module Returns ASCII Art & Text in Many Different Variations Depending on The Called Function."  ,
    long_description               = open("README.md").read()                                                                               ,
    long_description_content_type  = "text/markdown"                                                                                        ,
    author                         = "Anvil"                                                                                                ,
    author_email                   = "_@chimera.rip"                                                                                        ,
    url                            = "https://github.com/vChimera/dma"                                                                      ,
    packages                       = find_packages()                                                                                        ,
    classifiers                    = [
        "Programming Language :: Python :: 3"                                                                                               ,
        "License :: OSI Approved :: MIT License"                                                                                            ,
        "Operating System :: OS Independent"                                                                                                ,
    ]                                                                                                                                       ,
    python_requires                = ">=3.6"                                                                                                ,
)
